package net.rutles.movieplayer;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.media.MediaPlayer;
import android.media.MediaPlayer.OnCompletionListener;
import android.media.MediaPlayer.OnErrorListener;
import android.media.MediaPlayer.OnPreparedListener;
import android.os.Bundle;
import android.os.Environment;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.MediaController;
import android.widget.Spinner;
import android.widget.Toast;
import android.widget.VideoView;

public class MoviePlayer extends Activity 
	implements
	OnClickListener,
	DialogInterface.OnClickListener,
	OnPreparedListener,
	OnCompletionListener,
	OnErrorListener{
	
	private Spinner spinner;
	private Button button;
	private VideoView videoView;
	private String[] videoList;
	private String videoPath;
	private ProgressDialog progressDialog;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		if(!sdcardReadReady()){
			myAlert(getString(R.string.error_sd));
			return;
		}
		
		String rootDir = Environment.getExternalStorageDirectory().getPath();
		File videoDir = new File(rootDir + "/Movies");

		if(!videoDir.exists()){
			myAlert(getString(R.string.error_folder));
			return;
		}

		videoPath = videoDir.getPath() + "/";
		videoList = videoDir.list();

		List<String> tmp = new ArrayList<String>();
		for(String s: videoList){
			if(s.endsWith("MP4") || s.endsWith("mp4"))
				tmp.add(s);
		}
		tmp.toArray(videoList);

		spinner = (Spinner)findViewById(R.id.Spinner01);
		spinner.setAdapter(new  ArrayAdapter<CharSequence>(
				this,
				android.R.layout.simple_spinner_item, 
				videoList
				));

		button = (Button)findViewById(R.id.Button01);
		button.setOnClickListener(this);

		videoView = (VideoView) findViewById(R.id.VideoView01);
		videoView.setMediaController(new MediaController(this));
		videoView.setOnPreparedListener(this);
		videoView.setOnCompletionListener(this);
		videoView.setOnErrorListener(this);
	}

	@Override
	public void onPrepared(MediaPlayer mp) {
		// TODO Auto-generated method stub
		progressDialog.dismiss();
		videoView.seekTo(0);
		videoView.start();
	}

	@Override
	public void onCompletion(MediaPlayer arg0) {
		// TODO Auto-generated method stub
		Toast.makeText(this, getString(R.string.completion), Toast.LENGTH_LONG).show();
	}

	@Override
	public boolean onError(MediaPlayer mp, int what, int extra) {
		// TODO Auto-generated method stub
		
		switch(what){
		case MediaPlayer.MEDIA_ERROR_SERVER_DIED:
		case MediaPlayer.MEDIA_ERROR_UNKNOWN:
			mp.stop();
			mp.release();
			mp = new MediaPlayer();
			Toast.makeText(this, getString(R.string.error_mp), Toast.LENGTH_LONG).show();
			return true;
		}
		return false;
	}

	protected void onPause() {
		super.onPause();
		if(videoView != null)
		videoView.stopPlayback();
	}

	@Override
	public void onClick(View v) {
		// TODO Auto-generated method stub

		if(v == button){
			int select = spinner.getSelectedItemPosition();
			try {
				videoView.stopPlayback();
				videoView.setVideoPath(videoPath + videoList[select]);

			} catch (Exception e) {
				Toast.makeText(this, "Exception: " + e.getMessage(), Toast.LENGTH_LONG).show();
			}
			
			progressDialog = new ProgressDialog(this);
			progressDialog.setTitle(R.string.app_name);
			progressDialog.setMessage(getString(R.string.prepared));
			progressDialog.show();
		}
			
	}
	
	@Override
	public void onClick(DialogInterface dialog, int which) {
		// TODO Auto-generated method stub
		if(which==DialogInterface.BUTTON_NEUTRAL){
			dialog.dismiss();
			finish();
		}
		
	}

	private boolean sdcardReadReady(){
		String state = Environment.getExternalStorageState();
		return (
		Environment.MEDIA_MOUNTED.equals(state) || 
		Environment
		.MEDIA_MOUNTED_READ_ONLY.equals(state)
		);
	}

	private void myAlert(String message){
		new AlertDialog.Builder(this)
		.setTitle(R.string.app_name)
		.setMessage(message)
		.setNeutralButton("OK", this)
		.show();
	}
}